import React from 'react';
import { DayPickerProps } from '../../types/DayPicker';
import { DayPickerSingleProps } from '../../types/DayPickerSingle';
import { DayClickEventHandler } from '../../types/EventHandlers';
/** Represents the value of a [[SelectSingleContext]]. */
export interface SelectSingleContextValue {
    /** The day that has been selected. */
    selected: Date | undefined;
    /** Event handler to attach to the day button to enable the single select. */
    onDayClick?: DayClickEventHandler;
}
/**
 * The SelectSingle context shares details about the selected days when in
 * single selection mode.
 *
 * Access this context from the [[useSelectSingle]] hook.
 */
export declare const SelectSingleContext: React.Context<SelectSingleContextValue | undefined>;
declare type SelectSingleProviderProps = {
    initialProps: DayPickerProps;
    children: React.ReactNode;
};
/** Provides the values for the [[SelectSingleProvider]]. */
export declare function SelectSingleProvider(props: SelectSingleProviderProps): JSX.Element;
declare type SelectSingleProviderInternal = {
    initialProps: DayPickerSingleProps;
    children: React.ReactNode;
};
export declare function SelectSingleProviderInternal({ initialProps, children }: SelectSingleProviderInternal): JSX.Element;
export {};
